@@ -15,7 +15,7 @@ import six
 from botocore.exceptions import ClientError
 import json
 
-VERSION = "4.1.4"
+VERSION = "4.1.6"
 
 
 def connect(instance: object, args: argparse.Namespace):
@@ -381,7 +381,7 @@ def main():
         exit(0)
 
     if sys.stdin.isatty():
-        print('Querying AWS for EC2 instances in {region} region...\n'.format(**args.__dict__))
+        print('EC2 instances in {region} region:\n'.format(**args.__dict__))
         display_instances(instances)
 
     if not instances:
